

set -ex



test -L $PREFIX/lib/libnvfatbin.so.12.4.127
test -L $PREFIX/lib/libnvfatbin.so.12
test -L $PREFIX/targets/sbsa-linux/lib/libnvfatbin.so.12
test -f $PREFIX/targets/sbsa-linux/lib/libnvfatbin.so.12.4.127
bash test-rpath.sh
exit 0
